male_nouns = [
    'abbot',
    'actor',
    'bachelor',
    'baron',
    'beau',
    'benefactor',
    'billy-goat',
    'boar',
    'boy',
    'bridegroom',
    'brother',
    'buck',
    'buck-rabbit',
    'bull',
    'bull-calf',
    'bullock',
    'cock',
    'cock-sparrow',
    'colt',
    'count',
    'czar',
    'dog',
    'drake',
    'drone',
    'duke',
    'earl',
    'emperor',
    'enchanter',
    'father',
    'father-in-law',
    'fiance',
    'friar',
    'gander',
    'gentleman',
    'giant',
    'god',
    'grandfather',
    'hart',
    'hart',
    'he',
    'he-goat',
    'headmaster',
    'heir',
    'hero',
    'him',
    'host',
    'hound',
    'hunter',
    'husband',
    'king',
    'lad',
    'landlord',
    'lion',
    'lord',
    'male',
    'male-child',
    'man',
    'manservant',
    'marquis',
    'masseur',
    'master',
    'mayor',
    'milkman',
    'monk',
    'mr',
    'mister',
    'nephew',
    'patron',
    'peacock',
    'peer',
    'postman',
    'postmaster',
    'prince',
    'prophet',
    'ram',
    'shepherd',
    'signor',
    'sir',
    'sire',
    'son',
    'son-in-law',
    'songster',
    'sorcerer',
    'stag',
    'stallion',
    'steer',
    'stepfather',
    'stepson',
    'steward',
    'sultan',
    'tempter',
    'tiger',
    'traitor',
    'tutor',
    'uncle',
    'viscount',
    'waiter',
    'widower',
    'wizard'
]
