female_nouns = [
    'abbess',
    'actress',
    'spinster',
    'baroness',
    'belle',
    'benefactress',
    'nanny-goat',
    'sow',
    'girl',
    'bride',
    'sister',
    'doe',
    'doe-rabbit',
    'cow',
    'cow-calf',
    'heifer',
    'hen',
    'hen-sparrow',
    'filly',
    'countess',
    'czarina',
    'bitch',
    'duck',
    'bee',
    'duchess',
    'countess',
    'empress',
    'enchantress',
    'mother',
    'mother-in-law',
    'fiancee',
    'nun',
    'goose',
    'lady',
    'giantess',
    'goddess',
    'grandmother',
    'hind',
    'roe',
    'she',
    'she-goat',
    'headmistress',
    'heiress',
    'heroine',
    'her',
    'hostess',
    'brach',
    'huntress',
    'wife',
    'queen',
    'lass',
    'landlady',
    'lioness',
    'lady',
    'female',
    'female-child',
    'woman',
    'maidservant',
    'marchioness',
    'masseuse',
    'mistress',
    'mayoress',
    'milkmaid',
    'nun',
    'mrs',
    'missus',
    'niece',
    'patroness',
    'peahen',
    'peeress',
    'postwoman',
    'postmistress',
    'princess',
    'prophetess',
    'ewe',
    'shepherdess',
    'signora',
    'madam',
    'dam',
    'daughter',
    'daughter-in-law',
    'songstress',
    'sorceress',
    'hind',
    'mare',
    'heifer',
    'stepmother',
    'stepdaughter',
    'stewardess',
    'sultana',
    'temptress',
    'tigress',
    'traitress',
    'governess',
    'aunt',
    'viscountess',
    'waitress',
    'widow',
    'witch'
]
