PLURAL_PRONOUNS = [
  'we', 'us', 'our', 'ours', 'ourselves',
  'yourselves',
  'they', 'them', 'their', 'theirs', 'themselves'
]

SINGULAR_PRONOUNS = [
  'I', 'me', 'my', 'mine', 'myself',
  'you', 'your', 'yours', 'yourself',
  'he', 'him', 'his', 'himself',
  'she', 'her', 'hers', 'herself',
  'it', 'its', 'itself'
]

MASCULINE_PRONOUNS = ['he', 'him', 'his', 'himself']

FEMININE_PRONOUNS = ['she', 'her', 'hers', 'herself']
